Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(466)

Unified Diff: chrome/browser/sync/test/integration/profile_sync_service_harness.cc

Issue 2551023006: [Sync] SyncEngine 1.5: Fix all backend references in PSS. (Closed)
Patch Set: Fix Android. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/test/integration/profile_sync_service_harness.cc
diff --git a/chrome/browser/sync/test/integration/profile_sync_service_harness.cc b/chrome/browser/sync/test/integration/profile_sync_service_harness.cc
index 6a4b4ce228a660f6ded16d3e0067e16dae7ee69a..4e552de4cffa9a4fee54372652d93496f0bc65b4 100644
--- a/chrome/browser/sync/test/integration/profile_sync_service_harness.cc
+++ b/chrome/browser/sync/test/integration/profile_sync_service_harness.cc
@@ -49,25 +49,25 @@ bool HasAuthError(ProfileSyncService* service) {
GoogleServiceAuthError::REQUEST_CANCELED;
}
-class BackendInitializeChecker : public SingleClientStatusChangeChecker {
+class EngineInitializeChecker : public SingleClientStatusChangeChecker {
public:
- explicit BackendInitializeChecker(ProfileSyncService* service)
+ explicit EngineInitializeChecker(ProfileSyncService* service)
: SingleClientStatusChangeChecker(service) {}
bool IsExitConditionSatisfied() override {
- if (service()->IsBackendInitialized())
+ if (service()->IsEngineInitialized())
return true;
// Backend initialization is blocked by an auth error.
if (HasAuthError(service()))
return true;
// Backend initialization is blocked by a failure to fetch Oauth2 tokens.
if (service()->IsRetryingAccessTokenFetchForTest())
return true;
// Still waiting on backend initialization.
return false;
}
- std::string GetDebugMessage() const override { return "Backend Initialize"; }
+ std::string GetDebugMessage() const override { return "Engine Initialize"; }
};
class SyncSetupChecker : public SingleClientStatusChangeChecker {
@@ -179,7 +179,7 @@ bool ProfileSyncServiceHarness::SetupSync(
// Now that auth is completed, request that sync actually start.
service()->RequestStart();
- if (!AwaitBackendInitialization()) {
+ if (!AwaitEngineInitialization()) {
return false;
}
@@ -246,14 +246,14 @@ bool ProfileSyncServiceHarness::AwaitQuiescence(
return QuiesceStatusChangeChecker(services).Wait();
}
-bool ProfileSyncServiceHarness::AwaitBackendInitialization() {
- if (!BackendInitializeChecker(service()).Wait()) {
- LOG(ERROR) << "BackendInitializeChecker timed out.";
+bool ProfileSyncServiceHarness::AwaitEngineInitialization() {
+ if (!EngineInitializeChecker(service()).Wait()) {
+ LOG(ERROR) << "EngineInitializeChecker timed out.";
return false;
}
- if (!service()->IsBackendInitialized()) {
- LOG(ERROR) << "Service backend not initialized.";
+ if (!service()->IsEngineInitialized()) {
+ LOG(ERROR) << "Service engine not initialized.";
return false;
}
@@ -49,25 +49,25 @@ bool HasAuthError(ProfileSyncService* service) {
return true;
- // Backend initialization is blocked by an auth error.
+ // Engine initialization is blocked by an auth error.
if (HasAuthError(service()))
return true;
@@ -49,25 +49,25 @@ bool HasAuthError(ProfileSyncService* service) {
if (HasAuthError(service()))
return true;
- // Backend initialization is blocked by a failure to fetch Oauth2 tokens.
+ // Engine initialization is blocked by a failure to fetch Oauth2 tokens.
if (service()->IsRetryingAccessTokenFetchForTest())
return true;
@@ -49,25 +49,25 @@ bool HasAuthError(ProfileSyncService* service) {
if (service()->IsRetryingAccessTokenFetchForTest())
return true;
- // Still waiting on backend initialization.
+ // Still waiting on engine initialization.
return false;
}

Powered by Google App Engine
This is Rietveld 408576698